==> explainaboard-0.11.2-py2.py3-none-any.whl: explainaboard/processors/chunking.py <==
"""A processor for the chunking task."""

from __future__ import annotations

from explainaboard import TaskType
from explainaboard.metrics.f1_score import F1ScoreConfig, SeqF1ScoreConfig
from explainaboard.metrics.metric import MetricConfig
from explainaboard.processors.processor_registry import register_processor
from explainaboard.processors.sequence_labeling import SeqLabProcessor
from explainaboard.utils.span_utils import BIOSpanOps


@register_processor(TaskType.chunking)
class ChunkingProcessor(SeqLabProcessor):
    """A processor for the chunking task."""

    @classmethod
    def task_type(cls) -> TaskType:
        """See Processor.task_type."""
        return TaskType.chunking

    @classmethod
    def default_metrics(
        cls, level='example', source_language=None, target_language=None
    ) -> list[MetricConfig]:
        """See Processor.default_metrics."""
        defaults: dict[str, list[MetricConfig]] = {
            'example': [
                SeqF1ScoreConfig(
                    name='F1',
                    source_language=source_language,
                    target_language=target_language,
                    tag_schema='bio',
                )
            ],
            'span': [
                F1ScoreConfig(
                    name='F1',
                    source_language=source_language,
                    target_language=target_language,
                    ignore_classes=[cls._DEFAULT_TAG],
                )
            ],
        }
        return defaults[level]

    @classmethod
    def _default_span_ops(cls) -> BIOSpanOps:
        return BIOSpanOps()

==> explainaboard-0.12.7-py2.py3-none-any.whl: explainaboard/processors/chunking.py <==
"""A processor for the chunking task."""

from __future__ import annotations

from explainaboard import TaskType
from explainaboard.metrics.f1_score import F1ScoreConfig, SeqF1ScoreConfig
from explainaboard.metrics.metric import MetricConfig
from explainaboard.processors.sequence_labeling import SeqLabProcessor
from explainaboard.utils.span_utils import BIOSpanOps


class ChunkingProcessor(SeqLabProcessor):
    """A processor for the chunking task."""

    @classmethod
    def task_type(cls) -> TaskType:
        """See Processor.task_type."""
        return TaskType.chunking

    @classmethod
    def default_metrics(
        cls,
        level: str = "example",
        source_language: str | None = None,
        target_language: str | None = None,
    ) -> dict[str, MetricConfig]:
        """See Processor.default_metrics."""
        defaults: dict[str, dict[str, MetricConfig]] = {
            "example": {
                "F1": SeqF1ScoreConfig(
                    source_language=source_language,
                    target_language=target_language,
                    tag_schema="bio",
                )
            },
            "span": {
                "F1": F1ScoreConfig(
                    source_language=source_language,
                    target_language=target_language,
                    ignore_classes=[cls._DEFAULT_TAG],
                )
            },
        }
        return defaults[level]

    @classmethod
    def _default_span_ops(cls) -> BIOSpanOps:
        return BIOSpanOps()
